function [lb ub]=create_bounds(Ptype,Pmean, Pvar)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%create_bounds.m
%
%This program:
%               -creates bounds from the prior densities for the constrained numerical optimization
%                   used to find the posterior mode
%
%Inputs:        Pmean: Prior mean
%               Pvar: Prior variance
%                           Note: for uniform distribution, Pmean and Pvar
%                           contain the bounds of the uniform distribution
%               Ptype: type of prior (norm, beta, gamma, invgamma, or
%                   uniform)
%
%Output:        ub: upper bound
%               lb: lower bound
%
%THIS VERSION: 1.0 March 27, 2009
%
%
%Copyright: Alexander Meyer-Gohde
%
%You are free to use/modify/redistribute this program so long as original
%authorship credit is given and you in no way impinge on its free
%distribution
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


tol=1e-4;

for i=1:length(Ptype)
if strcmp(Ptype{i}, 'norm')
lb(1,i)=-Inf;
ub(1,i)=Inf;
end
if strcmp(Ptype{i}, 'beta')
lb(1,i)=tol;
ub(1,i)=1-tol;
end
if strcmp(Ptype{i}, 'gamma')
lb(1,i)=tol;
ub(1,i)=Inf;
end
if strcmp(Ptype{i}, 'invgamma')
lb(1,i)=tol;
ub(1,i)=Inf;
end
if strcmp(Ptype{i}, 'uniform')
A=min([Pmean(i) Pvar(i)]);
B=max([Pmean(i) Pvar(i)]);
lb(1,i)=A+tol;
ub(1,i)=B-tol;
end
end
