function [prior_function]=create_priors(Pmean, Pvar, Ptype)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%create_priors.m
%
%This program:
%               -creates a prior density function for the vector of
%               parameters to be estimated, using the vector of means, the
%               vector of variances and the cell array of types defined as
%               strings
%               -the following distributions are included:
%               (1) Normal (Ptype='norm')
%               (2) Beta (Ptype='beta')
%               (3) Gamma (Ptype='gamma')
%               (4) Inverse Gamma (Ptype='invgamma')
%               (5) Uniform (Ptype='uniform' note that the upper and lower
%                       bounds are simply the largest and smallest of the integers
%                       entered into Pmean and Pvar when using the uniform
%                       distribution)
%Inputs:        Pmean: Prior mean
%               Pvar: Prior variance
%                           Note: for uniform distribution, Pmean and Pvar
%                           contain the bounds of the uniform distribution
%               Ptype: type of prior (norm, beta, gamma, invgamma, or
%                   uniform)
%
%Output:        prior_function: a function that returns the prior density
%                   for a given parameter vector 
%
%THIS VERSION: 1.0 March 27, 2009
%
%
%Copyright: Alexander Meyer-Gohde
%
%You are free to use/modify/redistribute this program so long as original
%authorship credit is given and you in no way impinge on its free
%distribution
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if length(Pmean)~=length(Pvar)||length(Pmean)~=length(Ptype)||length(Pvar)~=length(Ptype)
disp('Pmean, Pvar, Ptype are of different dimensions!')
disp('Make sure you have a mean, variance, and type for each parameter!')
else
for i=1:length(Pmean)
if strcmp(Ptype{i}, 'norm')
A=Pmean(i);
B=Pvar(i);
prior{1,i}=sprintf('*normpdf(x(%d),%.20e,%.20e)',i,A,B);
end
if strcmp(Ptype{i}, 'beta')
A=((1-Pmean(i))*Pmean(i)^2)/Pvar(i)-Pmean(i);
B=(((1-Pmean(i))*Pmean(i)^2)/Pvar(i)-Pmean(i))*(1/Pmean(i)-1);
prior{1,i}=sprintf('*betapdf(x(%d),%.20e,%.20e)',i,A,B);
end
if strcmp(Ptype{i}, 'gamma')
A=(Pmean(i)^2)\Pvar(i);
B=Pvar(i)\Pmean(i);
prior{1,i}=sprintf('*gampdf(x(%d),%.20e,%.20e)',i,A,B);
end
if strcmp(Ptype{i}, 'invgamma')
A=3/2+(1/4+Pmean(i)/Pvar(i))^(1/2);
B=1/(Pmean(i)*(A-1));
prior{1,i}=sprintf('*gampdf(1/x(%d),%.20e,%.20e)',i,A,B);
end
if strcmp(Ptype{i}, 'uniform')
A=min([Pmean(i) Pvar(i)]);
B=max([Pmean(i) Pvar(i)]);
prior{1,i}=sprintf('*unifpdf(x(%d),%.20e,%.20e)',i,A,B);
end
end
end
eval(sprintf('eval([''prior_function=@(x)1%s;''])',[prior{:}]))
