function [transforms inverse_transforms]=create_transforms(Ptype,varargin)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%create_tranforms.m
%
%This program:
%               Creates functions based on the prior distributions to
%               tranform the domains of the parameters to be unrestricted
%Input:         Ptype: type of prior used for domain transform (i.e. norm
%                   does not transform the domain, beta has the parameter
%                   restricted to [0,1], etc.
%               varargin: two vectors the same length as Ptype. Used only
%                   if a variable is restricted to a domain (a,b); the 
%                   domain is transformed by using a Ptype=uniform. Only 
%                   the i'th entries are used, where i indexes the
%                   parameter with this domain.
%Ouput:         transforms: a function that transforms the unrestricted domain back to the
%                   target domain
%               inverse_transforms: a function that transforms the target domain into the
%                   unrestricted domain
%
% Note: essentially, could recode, foregoing Ptype and just having two vectors of the
% domain limits using the transforms under uniform with nargin>1, but
% keeping the domain transform based on the priors might be easier for some
% users..
%
%THIS VERSION: 1.0 March 27, 2009
%
%
%Copyright: Alexander Meyer-Gohde
%
%You are free to use/modify/redistribute this program so long as original
%authorship credit is given and you in no way impinge on its free
%distribution
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

for i=1:length(Ptype)
if strcmp(Ptype{i}, 'norm')
transform{1,i}=sprintf('x(%d),',i);
inverse_transform{1,i}=sprintf('x(%d),',i);
end
if strcmp(Ptype{i}, 'beta')
transform{1,i}=sprintf('1/(1+exp(x(%d))),',i);
inverse_transform{1,i}=sprintf('log((1-x(%d))/x(%d)),',i,i);
end
if strcmp(Ptype{i}, 'gamma')
transform{1,i}=sprintf('exp(x(%d)),',i);
inverse_transform{1,i}=sprintf('log(x(%d)),',i);
end
if strcmp(Ptype{i}, 'invgamma')
transform{1,i}=sprintf('exp(x(%d)),',i);
inverse_transform{1,i}=sprintf('log(x(%d)),',i);
end
if strcmp(Ptype{i}, 'uniform')
if nargin>1
A=min(varargin{i,:});
B=max(varargin{i,:});
transform{1,i}=sprintf('%.20e+(%.20e-%.20e)/(1+exp(x(%d))),',A,B,A,i);
inverse_transform{1,i}=sprintf('log((%.20e-x(%d))/(x(%d)-%.20e)),',B,i,i,A);
else
transform{1,i}=sprintf('1/(1+exp(x(%d))),',i);
inverse_transform{1,i}=sprintf('log((1-x(%d))/x(%d)),',i,i);
end
end
end

eval(sprintf('eval([''transforms=@(x)[%s];''])',[transform{:}]))
eval(sprintf('eval([''inverse_transforms=@(x)[%s];''])',[inverse_transform{:}]))