function []=plots(results,Ptype,Pmean,Pvar,parameter_names)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%plots.m
%
%This program:
%               plots histograms of parameter draws, priors and posteriors
%
%Inputs:        results : draws from metropolis
%               Ptype: type of prior (norm, beta, gamma, invgamma, or
%                   uniform)
%               Pmean: Prior mean
%               Pvar: Prior variance
%                           Note: for uniform distribution, Pmean and Pvar
%                           contain the bounds of the uniform distribution
%               parameter_names: a cell array with strings containing
%                   parameter names
%
%
%
%THIS VERSION: 1.0 March 27, 2009
%
%
%Copyright: Alexander Meyer-Gohde
%
%You are free to use/modify/redistribute this program so long as original
%authorship credit is given and you in no way impinge on its free
%distribution
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


[junk parameters]=size(results);
figure;
for i=1:parameters
    subplot(parameters,1,i), hist(results(:,i),50);
    lg=legend(parameter_names{i});
    set(lg, 'Interpreter','LaTex')
end


for i=1:parameters
p = gkde(results(:,i));
min_B=min(results(:,i));
max_B=max(results(:,i));
x=min_B:(max_B-min_B)/100:max_B;
    if strcmp(Ptype{i}, 'norm')
    type='normpdf';
    A=Pmean(i);
    B=Pvar(i);
    eval(sprintf('eval([''y=%s(x,%.20e,%.20e);''])',type,A,B));
    end
    if strcmp(Ptype{i}, 'beta')
    type='betapdf';
    A=((1-Pmean(i))*Pmean(i)^2)/Pvar(i)-Pmean(i);
    B=(((1-Pmean(i))*Pmean(i)^2)/Pvar(i)-Pmean(i))*(1/Pmean(i)-1);
    eval(sprintf('eval([''y=%s(x,%.20e,%.20e);''])',type,A,B));
    end
    if strcmp(Ptype{i}, 'gamma')
    type='gampdf';
    A=(Pmean(i)^2)\Pvar(i);
    B=Pvar(i)\Pmean(i);
    eval(sprintf('eval([''y=%s(x,%.20e,%.20e);''])',type,A,B));
    end
    if strcmp(Ptype{i}, 'invgamma')
    type='gampdf';
    A=3/2+(1/4+Pmean(i)/Pvar(i))^(1/2);
    B=1/(Pmean(i)*(A-1));
    eval(sprintf('eval([''y=%s(1./x,%.20e,%.20e);''])',type,A,B));
    end
    if strcmp(Ptype{i}, 'uniform')
    type='unifpdf';
    A=min([Pmean(i) Pvar(i)^(1/2)]);
    B=max([Pmean(i) Pvar(i)^(1/2)]);
    eval(sprintf('eval([''y=%s(x,%.20e,%.20e);''])',type,A,B));
    end
figure;
hold on
plot(p.x,p.f,'r','linewidth',2)
plot(x,y,'k','linewidth',2)
legend('Posterior', 'Prior')
title(['Prior and Posterior of ' parameter_names{i}],'Interpreter','LaTex')
hold off
end

